module UserCenter
  module Services
    class ClientService

      def self.create(org, opts)
        opts = opts.with_indifferent_access
        client = Client.find_by(organization_id: org.id)
        return client if client.present?

        if AppSettings.ikcrm?
          client = ikcrm_create(org, opts)
        elsif AppSettings.wxwork?
          client = lxcrm_create(org, opts)
        elsif AppSettings.dingtalk?
          client = dingcrm_create(org, opts)
        end

        client
      end

      def self.ikcrm_create(org, opts)
        ad_source = opts[:ad_source]
        source = opts[:source]

        client = Client.create(
          name: org.name,
          organization_id: org.id,
          account_type: :trial_account,
          source: Client.sources[source],
          ad_source: ad_source,
          users_count: Organization.trial_account_default_users_count,
          expires_at: Organization.trial_account_default_expires_at,
          version: 0
        )
        client.create_client_profile!

        client
      end

      def self.lxcrm_create(org, opts)
        source = opts[:source]
        wx_permission_type = :wx_free_permission
        users_count = 8
        expires_at = 100.years.from_now

        client = Client.create(
          name: org.name,
          organization_id: org.id,
          account_type: :trial_account,
          wx_status: :wx_status_normal,
          wx_permission_type: wx_permission_type,
          wx_account_type: :wx_trial_account,
          source: Client.sources[source],
          users_count: users_count,
          expires_at: expires_at,
          version: 0
        )
        client.create_client_profile!

        client
      end

      def self.dingcrm_create(org, opts)
      end

    end
  end
end