module UserCenter
  module Services
    class HashWxPusher
      class << self

        def send_corp_oa_message(user, params = {})
          return unless user

          opts = {
            uid_list: [user.uid]
          }.merge!(params).with_indifferent_access

          if opts[:msg_type].eql?('textcard') && opts[:url].blank?
            opts[:url] = wx_message_url(user.organization.oid, nil)
          end

          service = UserCenter::Services::MessageService.new(user.organization)
          service.send_wx_message(opts)
        rescue => e
          ::UserCenter::UcLogger.log_error "Wx send_corp_oa_message error: #{e.message}"
          e.backtrace.each { |msg| ::UserCenter::UcLogger.log_error msg }
        end

        def send_notification_text_card_message(notify_hash)
          user = User.find_by(notify_hash[:user_id])
          return unless user

          opts = {
            msg_type: 'textcard',
            title: notify_hash[:title],
            description: wx_message_description(notify_hash),
            url: wx_message_url(user.organization.oid, notify_hash)
          }

          send_corp_oa_message(user, opts)
        end

        def wx_message_description(notify_hash)
          content = notify_hash[:body]
          if notify_hash[:subject_type] == "Event"
            related = [
              notify_hash[:extras][:related_item_model_name_human].presence,
              notify_hash[:extras][:related_item_title].presence
            ].compact
            if related.size == 2
              content = "#{content} #{related.join('：')}"
            end
          end
          content
        end

        def wx_message_url(oid, notify_hash)
          url = URI(CrossSites.crm_base_host)
          url.path = '/wx/home'

          opts = {
            oid: oid,
            mobile_redirect_uri: wx_mobile_message_path(notify_hash),
            pc_redirect_uri: wx_pc_message_path(notify_hash)
          }

          url.query = opts.to_query
          url.to_s
        end

        def wx_mobile_message_path(notify_hash)
          return if notify_hash.blank?

          entity_name = notify_hash[:subject_type].to_s
          subject = notify_hash[:subject_type].classify.constantize.find_by(id: notify_hash[:subject_id])
          path = if entity_name == 'Event'
            _event_url = notify_hash[:notify_type] == 'notify_dealed_remind' ? "/calendar?date=#{Date.today.to_s}" :
            "/#{entity_name.tableize}/#{notify_hash[:subject_id]}/event"
            _event_url.chomp('/')
          elsif entity_name == 'ImportHistory'
            URI(URI.encode(subject.try(:file_path)))
          elsif notify_hash[:notify_type] == 'notify_approve_received_payment'
            "/contracts/#{notify_hash[:extras][:contract_id]}/show_received_payment/#{notify_hash[:extras][:contract_received_payment_id]}"
          elsif notify_hash[:notify_type] == 'notify_birthday_remind' && notify_hash[:subject_type] == "Contact" && subject.present?
            "/customers/#{subject.customer.id}/list-contact"
          elsif notify_hash[:extras].present? and notify_hash[:extras][:wxwork_msg_url].present?
            notify_hash[:extras][:wxwork_msg_url]
          else
            URI(URI.encode(notify_hash[:path])).path.chomp('/')
          end

          URI.decode_www_form_component(path.to_s)
        rescue
          nil
        end

        def wx_pc_message_path(notify_hash)
          return if notify_hash.blank?

          entity_name = notify_hash[:subject_type].to_s
          subject = notify_hash[:subject_type].classify.constantize.find_by(id: notify_hash[:subject_id])
          path = if entity_name == 'ImportHistory' && subject.present? && subject.has_error_data
            URI(URI.encode(subject.try(:file_path)))
          else
            URI(URI.encode(notify_hash[:path])).path
          end

          URI.decode_www_form_component(path.to_s)
        end

      end
    end
  end
end