module UserCenter
  module Services
    class MessageService
      attr_accessor :org, :send_data

      def initialize(org)
        @org = org
      end

      def send_wx_message(opts = {})
        opts = opts.merge(channel: 'wx')
        opts[:mq_queue] ||= 'usual'
        send_data = generate_message(opts)

        send_message(send_data, opts[:mq_queue])
      end

      def send_ding_message(opts = {})
        opts = opts.merge(channel: 'ding')
        opts[:mq_queue] ||= 'usual'
        send_data = generate_message(opts)

        send_message(send_data, opts[:mq_queue])
      end

      # mq_queue = usual 或者 mq_queue = frequent， usual 代表业务使用的队列，frequent代表 频繁消息通知
      def send_message(send_data, mq_queue)
        RabbitmqPublisher.publish(send_data.to_json, mq_queue == 'usual')
      end

      def generate_message(opts)
        head_params = generate_message_head(opts)
        body_params = generate_message_body(opts)
        head_params.merge(body_params)
      end

      def generate_message_head(opts = {})
        opts[:to_all] ||= false
        opts[:uid_list] ||= []
        opts[:did_list] ||= []

        toAll = opts[:to_all]
        uidList = opts[:uid_list]
        didList = opts[:did_list]
        channel = opts[:channel]

        {
          appToken: CrossSites['user_center']['app_token'],
          channel: channel,
          oid: org.oid,
          toAll: toAll,
          uidList: uidList,
          didList: didList
        }
      end

      def generate_message_body(opts = {})
        msg_type = opts[:msg_type]
        body_params = HashWithIndifferentAccess.new

        case msg_type
        when 'text'
          body_params.merge!(msgtype: msg_type, text: { content: opts[:content] })
        when 'image'
          body_params.merge!(msgtype: msg_type, image: { media_id: opts[:media_id] })
        when 'voice'
          body_params.merge!(msgtype: msg_type, voice: { media_id: opts[:media_id] })
        when 'video'
          body_params.merge!(msgtype: msg_type, video: {
            media_id: opts[:media_id],
            title: opts[:title],
            description: opts[:description]
          })
        when 'file'
          body_params.merge!(msgtype: msg_type, file: { media_id: opts[:media_id] })
        when 'textcard'
          body_params.merge!(msgtype: msg_type, textcard: {
            title: opts[:title],
            description: opts[:description],
            url: opts[:url],
            btntxt: opts[:btntxt]
          })
        when 'news'
          body_params.merge!(msgtype: msg_type, news: { articles: opts[:articles] })
        when 'mpnews'
          body_params.merge!(msgtype: msg_type, news: { articles: opts[:articles] })
        else
          ::UserCenter::UcLogger.log_info "Wx generate_message_body opts: #{opts}"
          body_params = HashWithIndifferentAccess.new
        end

        { msg: body_params }
      end
    end
  end
end

=begin
  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'text',
    content: 'xxx'
  }

  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'image',
    media_id: '1aLwXBx2Me0WH0lePENd5zgNBA1pQzTVvfA4N78UGeN-71EvQpwQaEgVoPD0A5vVO',
  }

  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'voice',
    media_id: '1aLwXBx2Me0WH0lePENd5zgNBA1pQzTVvfA4N78UGeN-71EvQpwQaEgVoPD0A5vVO',
  }

  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'video',
    media_id: '1aLwXBx2Me0WH0lePENd5zgNBA1pQzTVvfA4N78UGeN-71EvQpwQaEgVoPD0A5vVO',
    title: 'xxx',
    description: 'xxx'
  }

  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'file',
    media_id: '1aLwXBx2Me0WH0lePENd5zgNBA1pQzTVvfA4N78UGeN-71EvQpwQaEgVoPD0A5vVO',
  }

  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'textcard',
    title: 'xxx',
    description: 'xxx',
    url: 'http://test.e1.ikcrm.com/wx/1/1/home?corp_id=wx62011238322ec3ea&agent_id=1000013&pc_redirect_uri=%2Fcustomers&mobile_redirect_uri=%2Fcustomers'
  }

  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'news',
    articles: [
      {
        title: "中秋节礼品领取",
        description: "今年中秋节公司有豪礼相送",
        url: "http://www.ikcrm.com",
        picurl: "http://res.mail.qq.com/node/ww/wwopenmng/images/independent/doc/test_pic_msg1.png"
      }
    ]
  }

  opts = {
    to_all: false,
    uid_list: [1,2],
    did_list: [1,2],
    msg_type: 'mpnews',
    articles: [
      {
        title: "Title",
        thumb_media_id: "1aLwXBx2Me0WH0lePENd5zgNBA1pQzTVvfA4N78UGeN-71EvQpwQaEgVoPD0A5vVO",
        autho: "Author",
        content_source_url: "http://www.baidu.com",
        content: "Content",
        digest: "Digest description"
      }
    ]
  }


  mq_queue = usual 或者 mq_queue = frequent， usual 代表业务使用的队列，frequent代表 频繁消息通知
  service = UserCenter::Services::MessageService.new(org)
  service.send_wx_message(opts)
=end
