module UserCenter
  module Services
    class PackageServices

      def self.cache_info(oid)
        UcPackageCache.new(oid).fetch {
          info = self.info(oid)

          if info['code'] == 0
            {
              oid: info['data']['organizationOid'],
              license_type: info['data']['licenseType'],
              license_count: info['data']['licenseCount'],
              expired_at: time_parse_from_milliseconds(info['data']['expiredAt']),
              registered_at: time_parse_from_milliseconds(info['data']['registeredAt']),
              started_at: time_parse_from_milliseconds(info['data']['startedAt']),
              version: info['data']['version']
            }.with_indifferent_access
          else
            {}
          end
        }
      end

      def self.info(oid)
        opts = {
          oid: oid
        }
        res = Trans::HttpHandler.get(Trans::Router.get_package_url, opts)
      end

      def self.time_parse_from_milliseconds(time)
        if time.present?
          Time.strptime(time.to_s, '%Q')
        else
          nil
        end
      end

    end
  end
end

# expiredAt 过期时间
# licenseCount 开通工号数量
# licenseType 版本类别: 1:免费版/2:付费版/3:试用版/4:已关闭
# organizationOid 主键
# registeredAt 注册时间
# startedAt 开始时间
# version 产品版本：1:专业版/2:基础版/3:旗舰版