module UserCenter
  module Services
    class UserService

      attr_accessor :user, :user_token_key, :user_valid_password_key

      APP_HEADER = { "accessToken" => CrossSites[:user_center]['access_token'] }

      def initialize(user = nil)
        @user = user
        @user_valid_password_key = "user_#{@user.uid}_valid_password_key" if @user
        @user_token_key = "user_#{@user.uid}_token" if @user
      end

      def get_credence
        _url = Trans::Router.credence_url
        _params = { uid: @user.uid }
        _headers = APP_HEADER

        res = Trans::HttpHandler.get(_url, _params, _headers)

        res[:data][:credence]
      end

      def get_user_token
        if $redis.get(@user_token_key).blank?
          _url = Trans::Router.user_token_url
          _params = { credence: get_credence }
          _headers = APP_HEADER

          res = Trans::HttpHandler.get(_url, _params, _headers)

          $redis.set(@user_token_key, res[:data][:userToken], ex: res[:data][:expiration].gsub('HOURS','').to_i.hours - 30.minutes)
        end

        $redis.get(@user_token_key)
      end

      # 忘记密码时先使用手机号获取随机码
      def random
        _url = Trans::Router.random_url
        _params = { phone: @user.phone }
        _headers = APP_HEADER

        res = Trans::HttpHandler.get(_url, _params, _headers)

        res[:data]
      end

      # 忘记密码使用获取到的随机码和新密码重置
      def forget_password(password, confirm_password)
        _url = Trans::Router.forget_password_url
        _params = {
          random: random,
          phone: @user.phone,
          passwordOne: password,
          passwordTwo: confirm_password
        }
        _headers = APP_HEADER

        res = Trans::HttpHandler.post(_url, _params, _headers)

        res[:code].to_i == 0
      end

      # 用户重置自己密码先验证原密码正确，获取随机码
      def valid_password(password)
        _url = Trans::Router.valid_password_url
        _params = {
          uid: @user.uid,
          oldPassword: password
        }
        _headers = APP_HEADER

        res = Trans::HttpHandler.post(_url, _params, _headers)

        $redis.set(@user_valid_password_key, res[:randomCode], ex: 1.hours) if res[:code].to_i == 0

        res[:code].to_i == 0
      end

      # 使用验证原密码获取的随机码设置新密码
      def reset_password(password, confirm_password)
        _url = Trans::Router.reset_password_url
        _params = {
          randomCode: $redis.get(@user_valid_password_key),
          uid: @user.uid,
          newPasswordOne: password,
          newPasswordTwo: confirm_password
        }
        _headers = APP_HEADER

        res = Trans::HttpHandler.post(_url, _params, _headers)
        $redis.del(@user_valid_password_key)

        res[:code].to_i == 0
      end

      # 用户编辑个人基本信息
      def update_personal_info(user_params)
        _url = Trans::Router.update_personal_info_url
        _params = to_uc_user_params(user_params)
        _headers = APP_HEADER

        res = Trans::HttpHandler.post(_url, _params, _headers)

        res[:code].to_i == 0
      end

      # 用户更换绑定手机号
      def update_binding_phone(phone)
        _url = Trans::Router.update_binding_phone_url
        _params = { uid: @user.uid, phone: phone }
        _headers = APP_HEADER

        res = Trans::HttpHandler.post(_url, _params, _headers)

        res[:code].to_i == 0
      end

      private

      def to_uc_user_params(opts = {})
        to_uc_params = opts.with_indifferent_access
                           .slice(:name, :email, :gender, :job, :avatarUrl)
                           .merge({ uid: @user.uid })
      end
    end
  end
end