module UserCenter
  module Services
    module Wx
      AccountType = {
        free:    0, # 免费帐号
        payment: 1, # 付费帐号
        invalid: 2, # 无效帐号
        fail:    3  # 参数或者状态引起无法判断正确的帐号
      }.with_indifferent_access.freeze

      AccountStatus = {
        ok:                     0,
        exceed_user_limitation: 1,
        fail:                   3  # 获取权限失败, 公司未激活该套件
      }.with_indifferent_access.freeze

      FREE_USERS_COUNT = 8

      class AccountService

        attr_reader :org, :package

        def initialize(org)
          @org = org
          @package = UserCenter::Services::PackageServices.cache_info(@org.oid)
        end

        def account_type
          if @package.blank?
            return AccountType.fetch(:invalid)
          end

          @package[:license_type].in?([2,3]) ? AccountType.fetch(:payment) : AccountType.fetch(:free)
        end

        def account_type_text
          AccountType.invert.fetch(account_type)
        end

        def subscriber_status
          return 'active' if @package.present?
        end

        def expired?
          DateTime.now > @package[:expired_at] if @package.present?
        end

        def expired_at
          @package[:expired_at].to_s rescue nil
        end

        def started_at
          @package[:started_at].to_s rescue nil
        end

        def status
          if @package.blank?
            return AccountStatus.fetch(:fail)
          end

          if @package[:license_type] == 3 && org.users_count.to_i > FREE_USERS_COUNT
            return AccountStatus.fetch(:exceed_user_limitation)
          end

          AccountStatus.fetch(:ok)
        end

        def status_text
          AccountStatus.invert.fetch(status)
        end

        def trial_payment_lt_15d?
          @org.can_trial?
        end

        def in_trial_lt_15d?
          @org.on_trial?
        end

      end
    end
  end
end
