module UserCenter
  module Services
    module Wx
      class MediaService
        attr_accessor :oid, :user, :access_token

        def initialize(user)
          @user = user
          @oid = user.organization.oid
        end

        def create_attachments(medias)
          create_attachments_for(medias) do |attach, url|
            AttachmentUrlCreateWorker.perform_async(attach.id, url)
          end
        end

        def sync_create_attachments(medias)
          create_attachments_for(medias) do |attach, url|
            AttachmentUrlCreateWorker.new.perform(attach.id, url)
          end
        end

        def create_audios(medias)
          medias.map do |media|
            audio = Audio.create(wx_media_id: media[:id], duration: media[:duration])
            media_url = get_media_url(oid: oid, media_id: media[:id])
            AudioUrlCreateWorker.perform_async(audio.id, media_url, file_type: 'audio/amr')
            audio
          end
        end

        def create_attachments_for(medias)
          medias.map do |media|
            attachment = Attachment.create(wx_media_id: media[:id], user: user, organization_id: user.organization.id)
            media_url = get_media_url(oid: oid, media_id: media[:id])

            yield attachment, media_url
            attachment
          end
        end

        def get_media_url(oid: , media_id: )
            params = {access_token: get_access_token(oid), media_id: media_id}
            _url = "#{WxSetting.qyapi_host}/cgi-bin/media/get"
            _url << "?#{params.to_query}"
            _url
        end

        def get_access_token(oid)
          return @access_token if @access_token.present?

          opts = {
            oid: oid
          }
          res = Trans::HttpHandler.get(Trans::Router.get_wx_corp_access_token_url, opts)
          if res['code'] == 0
            @access_token = res['data']['accessToken']
          end

          @access_token
        end
      end

    end
  end
end