module UserCenter
  module Services
    module Wx
      class TransferIdServices

        class << self

          def get_uids_by_wx_userids(oid, *userids)
            userids.flatten!

            _url = UserCenter::Trans::Router.get_uid_by_wx_userid_url
            _params = { oid: oid, wxUseridList: userids }

            res = UserCenter::Trans::HttpHandler.post(_url, _params)

            if res[:code].to_s.eql?('0')
              userids.length == 1 ? res[:data][userids[0]] : res[:data]
            else
              nil
            end
          end
          alias_method :get_uid_by_wx_userid, :get_uids_by_wx_userids

          def get_wx_userids_by_uids(oid, *uids)
            uids.flatten!

            _url = UserCenter::Trans::Router.get_wx_userid_by_uid_url
            _params = { oid: oid, uids: uids }

            res = UserCenter::Trans::HttpHandler.post(_url, _params)

            if res[:code].to_s.eql?('0')
              uids.length == 1 ? res[:data][uids[0].to_s] : res[:data]
            else
              nil
            end
          end
          alias_method :get_wx_userid_by_uid, :get_wx_userids_by_uids

          def get_oid_by_wx_corp_id(corp_id)
            get_oid_key = "#{corp_id}_to_oid"
            if $redis.get(get_oid_key).blank?

              _url = UserCenter::Trans::Router.get_oid_by_wx_corp_id_url
              _params = { corpId: corp_id }

              res = UserCenter::Trans::HttpHandler.get(_url, _params)

              if res[:code].to_s.eql?('0')
                $redis.set(get_oid_key, res[:data][:oid], ex: 7.days)
              else
                return nil
              end
            end
            $redis.get(get_oid_key).to_i
          end

          def get_wx_corp_id_and_agent_id_by_oid(oid)
            get_corp_id_key = "#{oid}_to_wx_corp_id"
            get_agent_id_key = "#{oid}_to_agent_id"
            if $redis.get(get_corp_id_key).blank? || $redis.get(get_agent_id_key).blank?

              _url = UserCenter::Trans::Router.get_wx_corp_id_by_oid_url
              _params = { oid: oid }

              res = UserCenter::Trans::HttpHandler.get(_url, _params)

              if res[:code].to_s.eql?('0')
                $redis.set(get_corp_id_key, res[:data][:corpId], ex: 7.days)
                $redis.set(get_agent_id_key, res[:data][:agentId], ex: 7.days)
              else
                return ['','']
              end
            end

            [$redis.get(get_corp_id_key), $redis.get(get_agent_id_key)]
          end

          def get_wx_corp_id_by_oid(oid)
            get_wx_corp_id_and_agent_id_by_oid(oid)[0]
          end

          def get_agent_id_by_oid(oid)
            get_wx_corp_id_and_agent_id_by_oid(oid)[1]
          end

          def get_suite_token_by_suite_id(suite_id)
            _url = UserCenter::Trans::Router.get_suite_token_url
            _params = { suiteId: suite_id }

            res = UserCenter::Trans::HttpHandler.get(_url, _params)

            res[:data][:token]
          end

          def clear_agent_id_cache(oid)
            get_agent_id_key = "#{oid}_to_agent_id"
            $redis.del(get_agent_id_key)
          end

        end
      end
    end
  end
end