module UserCenter
  module Services
    class WxPusher
      class << self

        def send_corp_oa_message(user, params = {})
          return unless user

          opts = {
            uid_list: [user.uid]
          }.merge!(params).with_indifferent_access

          if opts[:msg_type].eql?('textcard') && opts[:url].blank?
            opts[:url] = wx_message_url(user.organization.oid, nil)
          end

          service = UserCenter::Services::MessageService.new(user.organization)
          service.send_wx_message(opts)
        rescue => e
          ::UserCenter::UcLogger.log_error "Wx send_corp_oa_message error: #{e.message}"
          e.backtrace.each { |msg| ::UserCenter::UcLogger.log_error msg }
        end

        def send_notification_text_card_message(notification)
          user = notification.user
          return unless user

          opts = {
            msg_type: 'textcard',
            title: notification.title,
            description: wx_message_description(notification),
            url: wx_message_url(user.organization.oid, notification)
          }

          send_corp_oa_message(user, opts)
        end

        def wx_message_description(notification)
          content = notification.body
          if notification.subject_type == "Event"
            related = [
              notification.extras[:related_item_model_name_human].presence,
              notification.extras[:related_item_title].presence
            ].compact
            if related.size == 2
              content = "#{content} #{related.join('：')}"
            end
          end
          content
        end

        def wx_message_url(oid, notification)
          url = URI(CrossSites.crm_base_host)
          url.path = '/wx/home'

          opts = {
            oid: oid,
            mobile_redirect_uri: wx_mobile_message_path(notification),
            pc_redirect_uri: wx_pc_message_path(notification)
          }

          url.query = opts.to_query
          url.to_s
        end

        def wx_mobile_message_path(notification)
          return if notification.blank?

          entity_name = notification.subject_type.to_s
          path = if entity_name == 'Event'
            _event_url = notification.notify_type == 'notify_dealed_remind' ? "/calendar?date=#{Date.today.to_s}" :
            "/#{entity_name.tableize}/#{notification.subject_id}/event"
            _event_url.chomp('/')
          elsif entity_name == 'ImportHistory'
            URI(URI.encode(notification.subject.try(:file_path)))
          elsif notification.notify_type == 'notify_approve_received_payment'
            "/contracts/#{notification.extras[:contract_id]}/show_received_payment/#{notification.extras[:contract_received_payment_id]}"
          elsif notification.notify_type == 'notify_birthday_remind' && notification.subject_type == "Contact" && notification.subject.present?
            "/customers/#{notification.subject.customer.id}/list-contact"
          elsif notification.extras.present? and notification.extras[:wxwork_msg_url].present?
            notification.extras[:wxwork_msg_url]
          elsif entity_name == 'Lead' && notification.notify_type.in?(%w(notify_flow_into_common_pool notify_transfer_common_pool))
            "/"
          else
            URI(URI.encode(notification.content_path)).path.chomp('/')
          end

          URI.decode_www_form_component(path.to_s)
        rescue
          nil
        end

        def wx_pc_message_path(notification)
          return if notification.blank?

          entity_name = notification.subject_type.to_s
          subject = notification.subject
          path = if entity_name == 'ImportHistory' && subject.present? && subject.has_error_data
            URI(URI.encode(notification.subject.try(:file_path)))
          else
            URI(URI.encode(notification.content_path)).path
          end

          URI.decode_www_form_component(path.to_s)
        end

      end
    end
  end
end