### TODO 处理网络超时异常
module UserCenter
  module Trans
    class HttpHandler
      HTTParty::Basement.default_options.update(verify: false)
      APP_TOKEN = CrossSites['user_center']['app_token']

      TIMEOUT = 10
      UC_SUCCESS_CODE = 0
      ACCEPT_HEADER = {"Accept" => "application/json;"}
      JSON_HEADER = {'Content-Type' => 'application/json', 'appToken' => APP_TOKEN}


      def self.get(url, params = {}, header = {})
        headers = HashWithIndifferentAccess.new
        headers.merge! ACCEPT_HEADER
        headers.merge! JSON_HEADER
        headers.merge! header


        start_time = Time.now
        body = {}
        begin
          response = HTTParty.get(
              url,
              query: params,
              headers: headers,
              timeout: TIMEOUT
          )
          exec_time = Time.now - start_time
          ::UserCenter::UcLogger.logger.info "get_json: url = '#{url}', query = #{params}, headers = '#{headers}',exec_time = #{exec_time}, response = #{response.inspect}"
          body = response.body
        rescue
          body[:msg] = "网络超时"
          body[:code] = -1
        end

        body = JSON.parse(body).with_indifferent_access if body.is_a? String

        unless body[:code].to_i.eql?(UC_SUCCESS_CODE)
          @errmethod = "GET"
          @errurl = url
          @errcode = body[:code]
          body.merge!(code: @errcode)
        end

        @errmethod = "GET"
        @errurl = url

        @errcode = UC_SUCCESS_CODE
        HashWithIndifferentAccess.new body
      end

      def self.post(url, params = {}, header = {})
        rescue_result = {code: -1, msg: "服务异常，请稍后重试"}

        headers = HashWithIndifferentAccess.new
        headers.merge! ACCEPT_HEADER
        headers.merge! JSON_HEADER
        headers.merge! header


        start_time = Time.now

        body = {}
        begin
          response = HTTParty.post(url.to_str, :body => params.to_json, :headers => headers, timeout: TIMEOUT)
          exec_time = Time.now - start_time
          ::UserCenter::UcLogger.logger.info "Success: post_json: url = #{url}, url = '#{url}', headers = '#{headers}',"\
                                 " data = #{params.inspect}, exec_time = #{exec_time}, response = #{response.inspect}"
          body = response.body
        rescue
          body[:msg] = "网络超时"
          body[:code] = -1
          ::UserCenter::UcLogger.logger.info "Network Timeout Error: post_json: url = #{url}, url = '#{url}', headers = '#{headers}',"\
                                 " data = #{params.inspect}"
        end

        if body.is_a? String
          body = JSON.parse(body).with_indifferent_access rescue rescue_result
        end

        unless body[:code].to_i.eql?(UC_SUCCESS_CODE)
          @errmethod = "POST"
          @errurl = url
          @errcode = body[:code]
          body.merge!(code: @errcode)
        end

        @errmethod = "POST"
        @errurl = url
        @errcode = UC_SUCCESS_CODE
        HashWithIndifferentAccess.new body
      end

    end
  end
end
