module UserCenter
  module Trans
    module Router
      BASE_URL = CrossSites['user_center']['host']
      APP_TOKEN = CrossSites['user_center']['app_token']
      LOGIN_CALLBACK_URL = CrossSites['user_center']['login_callback_url']

      def login_url
        BASE_URL + "/web/index.html?registered_way=normal_source&redirectUri=" + LOGIN_CALLBACK_URL + "&appToken=" + APP_TOKEN + "#/login"
      end

      def logout_url(current_uid)
        BASE_URL + "/web/index.html?" + "appToken=" + APP_TOKEN + "&redirectUri=" + LOGIN_CALLBACK_URL + "&type=logout&uid=#{current_uid}" + "#/login"
      end

      def verify_ticket_url
        BASE_URL + "/api/sso/verifyTicket"
      end

      def app_users_login_url
        BASE_URL + "/api/sso/app/users/login"
      end

      def sso_open_api_login_url
        BASE_URL + "/api/sso/openApi/login"
      end

      def app_phone_list
        BASE_URL + "/api/organization/app/phone/list"
      end

      def user_info_url
        BASE_URL + "/api/sso/getUserInfo"
      end

      # 请求忘记密码接口重置密码之前要先请求random接口，并把获取到的随机码作为忘记密码接口的参数
      def random_url
        BASE_URL + "/api/auth/random"
      end

      # 忘记密码接口
      def forget_password_url
        BASE_URL + "/api/user/management/forgetPassword"
      end

      # 验证用户密码是否正确，验证正确获取一个随机码，作为重置密码接口的参数
      def valid_password_url
        BASE_URL + "/api/app/user/checkLoginUserOldPassword"
      end

      # 重置密码接口，用于用户自己重置密码
      def reset_password_url
        BASE_URL + "/api/app/user/resetLoginUserPassword"
      end

      # 用户编辑自己基本信息
      def update_personal_info_url
        BASE_URL + "/api/app/user/updatePersonalInformation"
      end

      # 用户绑定手机号
      def update_binding_phone_url
        BASE_URL + "/api/app/user/updateBindingPhone"
      end

      def get_package_url
        BASE_URL + "/api/organization/getPackage"
      end

      # 用户中心部门和用户设置页面
      def department_url
        BASE_URL + "/web/index.html?appToken=" + APP_TOKEN + "#/department"
      end

      # 用户中心公司信息页面
      def organization_url
        BASE_URL + "/web/index.html?appToken=" + APP_TOKEN + "#/company"
      end

      # 用户中心账户信息页面
      def account_url
        BASE_URL + "/web/index.html?appToken=" + APP_TOKEN + "#/account"
      end

      # 根据手机号查应用和企业
      def check_user_url
        BASE_URL + "/api/user/management/getOrganizationAndApp"
      end

      # 注册企业
      def organization_register_url
        BASE_URL + "/api/organization/register"
      end

      # 通过uid获取credence
      def credence_url
        BASE_URL + "/api/auth/getCredenceByUid"
      end

      # 通过uid和credence获取userToken
      def user_token_url
        BASE_URL + "/api/auth/getTokensByUid"
      end

      # 获取jsapi签名
      def get_jsapi_signature_url
        BASE_URL + "/api/wx/getJsApiSignature"
      end

      # 获取jsagentConfig
      def get_jsagent_signature_url
        BASE_URL + "/api/wx/getJsAgentSignature"
      end

      # 根据企业微信应用免登获取的code换取用户信息
      def get_user_info_by_code_url
        BASE_URL + "/api/wx/getUserInfoByCode"
      end

      # 企业微信网页登录获取的authcode换取用户信息
      def get_login_info_by_auth_code_url
        BASE_URL + "/api/wx/getLoginInfoByAuthCode"
      end

      # 使用企业微信userid换取uid
      def get_wx_userid_by_uid_url
        BASE_URL + "/api/wx/getWxUseridByUid"
      end

      # 使用uid换取企业微信userid
      def get_uid_by_wx_userid_url
        BASE_URL + "/api/wx/getUidByWxUserid"
      end

      # 使用企业微信corp_id换取oid
      def get_oid_by_wx_corp_id_url
        BASE_URL + "/api/wx/getOidByCorpId"
      end

      # 使用oid换取企业微信corp_id
      def get_wx_corp_id_by_oid_url
        BASE_URL + "/api/wx/getCorpIdByOid"
      end

      # qrcode login
      def qrcode_login_url
        BASE_URL + "/api/wx/#{APP_TOKEN}/qrLogin"
      end

      def get_wx_corp_access_token_url
        BASE_URL + "/api/wx/getWxCorpAccessToken"
      end

      def get_external_contact_url
        BASE_URL + "/api/wx/getExternalContact"
      end

      # 根据suiteid获取token
      def get_suite_token_url
        BASE_URL + "/api/wx/getEncodingToken"
      end

      def get_register_callback_url(channel)
        BASE_URL + "/api/wx/#{channel}/register_callback"
      end

      extend self
    end
  end
end