module UserCenter
  class UcLogger
    attr_accessor :errors
    LOG_FILE = "#{Rails.root}/log/uc_gateway.log"
    ERROR_LOG_FILE = "#{Rails.root}/log/uc_gateway_errors.log"

    def self.logger
      @logger ||= ActiveSupport::TaggedLogging.new(ActiveSupport::Logger.new(LOG_FILE))
    end

    def self.error_logger
      @logger ||= ActiveSupport::TaggedLogging.new(ActiveSupport::Logger.new(ERROR_LOG_FILE))
    end

    def self.log_info(msg, uuid: nil)
      uuid ||= RequestStore.store[:request_uuid]
      logger.tagged(Time.now.strftime('%Y-%m-%d %H:%M:%S.%L'), uuid) {
        logger.info msg
      }
    end

    def self.log_error(msg, uuid: nil)
      uuid ||= RequestStore.store[:request_uuid]
      error_logger.tagged(Time.now.strftime('%Y-%m-%d %H:%M:%S.%L'), uuid) {
        error_logger.error msg
      }
    end

    def self.exception_log(e)
      ::UserCenter::UcLogger.error_logger.error "exception: #{e.message}"
      e.backtrace.each { |message| ::UserCenter::UcLogger.error_logger.error "exception: #{message}" }
    end
  end
end
